### Name: TileReadCel
### Title: TileReadCel
### Aliases: TileReadCel


### ** Examples
## Note that the following example only executes if the external data
## of the Starr R package is available which includes an artificial
## Affymetrix BPMAP file and corresponding CEL files.
path <- system.file("extdata", package = "Starr")
if (path != ""){
## define Affymetrix BPMAP file for probe mapping
bpmap.filename <- file.path(path, "Scerevisiae_tlg_chr1.bpmap")
## define Affymetrix CEL files
## here: file of control experiment (wt)
wt.filename <- file.path(path, "wt_IP_chr1.cel")
stopifnot(file.exists(bpmap.filename) && file.exists(wt.filename))

## read CEL file and return data.frame
## with information such as genomic localization
## of probes, GC content of probe sequences,
## and probe intensities.
## Note that group is '' (blank) for old Affy chr21/22arrays
## while it is "Hs" for other Human, "Mm" for Mouse, or "Dm"
## for Drosophila tiling array platforms.
wt.cel <- TileReadCel(cel.filename=wt.filename,
bpmap.filename=bpmap.filename,
group="", gc=TRUE, verbose=FALSE)

## getting an overview on the reported data.frame
str(wt.cel)

## investigating data
## e.g. plot density of intensities
pdf(file="wt_int_density.pdf")
plot(density(wt.cel$intensity), main="", xlab="Intensity")
dev.off()
## or GC bias with three GC content bins
pdf(file="wt_gc_bias.pdf")
boxplot(wt.cel$intensity ~ cut(wt.cel$gc,
breaks=c(0,0.36,0.52,Inf),right=FALSE),
xlab="GC content", ylab="Intensity")
dev.off()
## cleanup
rm(bpmap.filename, wt.filename, wt.cel)
}
rm(path)


