### Name: TileReadCustom
### Title: TileReadCustom
### Aliases: TileReadCustom


### ** Examples
## This example requires the custom-formatted files
## in the extdata folder of this package. Otherwise,
## it aborts with an error.
path <- system.file("extdata", package = "TileShuffle")
stopifnot(path != "")
## define filename to custom-formatted file
custom.filename <- file.path(path, "custom.txt")
stopifnot(file.exists(custom.filename))

## read custom-formatted file and return data.frame
## with information such as genomic localization
## of probes, GC content of probe sequences, and
## probe intensities.
custom <- TileReadCustom(custom.filename=custom.filename,
pmonly=TRUE, gc=TRUE, verbose=FALSE)

## getting an overview on the reported data.frame
str(custom)

## investigating data
## e.g. plot density of intensities
pdf(file="custom_int_density.pdf")
plot(density(custom$intensity), main="", xlab="Intensity")
dev.off()
## or GC bias with three GC content bins
pdf(file="custom_gc_bias.pdf")
boxplot(custom$intensity ~ cut(custom$gc,
breaks=c(0,0.36,0.52,Inf),right=FALSE),
xlab="GC content", ylab="Intensity")
dev.off()
## cleanup
rm(path, custom.filename, custom)


