### Name: TileShuffle
### Title: TileShuffle
### Aliases: TileShuffle


### ** Examples
## Note that the following example only executes if the external data
## of the Starr R package is available which includes an artificial
## Affymetrix BPMAP file and corresponding CEL files.
path <- system.file("extdata", package = "Starr")
if (path != ""){
## define Affymetrix BPMAP file for probe mapping
bpmap.filename <- file.path(path, "Scerevisiae_tlg_chr1.bpmap")
## define Affymetrix CEL files
## here: file of control experiment (wt)
wt.filename <- file.path(path, "wt_IP_chr1.cel")
## and files of real experiment with
## tagged Rpb3 with two replicates (ip)
ip.filename <- c(file.path(path, "Rpb3_IP_chr1.cel"),
file.path(path, "Rpb3_IP2_chr1.cel"))
stopifnot(file.exists(bpmap.filename) && all(file.exists(ip.filename)) &&
file.exists(wt.filename))

## identify highly expressed segments in IP state
## (only 100 permutations as example)
## Note that group is here '' (blank) for old Affy chr21/22 arrays
## but commonly it is "Hs" for Human, "Mm" for Mouse or "Dm" for Drosophila
TileShuffle(bpmap.filename=bpmap.filename, cel.filename=ip.filename,
input.type=2, group="", pmonly=TRUE, normalize=TRUE,
noofperms=100, winsize=200, qvalue=0.05,
gcnum=3, diff=FALSE, output.filename="ip_high.bed",
zscore.filename="ip_high_zscore.bed", verbose=FALSE)

## identify highly expressed segments in wt state
## (only 100 permutations as example)
TileShuffle(bpmap.filename=bpmap.filename, cel.filename=wt.filename,
input.type=2, group="", pmonly=TRUE, normalize=TRUE,
noofperms=100, winsize=200, qvalue=0.05,
gcnum=3, diff=FALSE, output.filename="wt_high.bed",
zscore.filename="wt_high_zscore.bed", verbose=FALSE)

## concatenate files
file.create("ip_and_wt_high.bed")
file.append("ip_and_wt_high.bed", "ip_high.bed")
file.append("ip_and_wt_high.bed", "wt_high.bed")

## identify highly and differentially expressed segments (highdiff)
## that are highly expressed in control or real experiment and
## significantly differentially expressed between both conditions
## (only 100 permutations as example)
## Note: common differential analysis without idenfying highdiff segments
## is executed simply by omitting the parameter 'regions.filename'
TileShuffle(bpmap.filename=bpmap.filename, cel.filename=wt.filename,
cel2.filename=ip.filename, input.type=2, group="",
pmonly=TRUE, normalize=TRUE, noofperms=100,
winsize=200,qvalue=0.05, gcnum=1, diff=TRUE,
regions.filename="ip_and_wt_high.bed",
output.filename="ip_and_wt_highdiff.bed",
zscore.filename="ip_and_wt_highdiff_zscore.bed",
verbose=FALSE)
## cleanup
rm(bpmap.filename, wt.filename, ip.filename)
}
rm(path)


